@@ -10,13 +10,15 @@
     cat("Pillai's trace: ", format(x$Pillai, ...), "\n")
     cat("\n")
     cat("Significance of Pillai's trace:\n")
+
+    cat("from F-distribution:  ", format.pval(x$p.Pillai), "\n")
     if (x$nperm > 0) {
-        cat("based on", x$nperm, "permutations: ")
+        cat("based on permutations: ")
         cat(x$p.perm,"\n")
+        cat(howHead(x$control), "\n")
     }
-    cat("from F-distribution: ", format.pval(x$p.Pillai), "\n\n")
     out <- rbind("Eigenvalues" = x$EigenValues, "Canonical Correlations" = x$CanCorr)
-    colnames(out) <- colnames(x$AA)
+    colnames(out) <- colnames(x$Cy)
     printCoefmat(out, ...)
     cat("\n")
     out <- rbind("RDA R squares" = x$RDA.Rsquares, "adj. RDA R squares" = x$RDA.adj.Rsq)
